# Use Cases

This section introduces various use cases of minto.
Each use case provides reference examples of how to solve various data-related challenges in research and development related to mathematical optimization using minto.

Of course, uses beyond these examples are possible. If you have requests like "Can this data challenge be solved?", please feel free to ask in the Community Discord.

